# Electrophysiology Testing Data

Collection of testing data in various electrophysiology file formats. The datasets in this repository are used within the [Neo](https://github.com/NeuralEnsemble/python-neo) project.

## Contributing

If you have small data files in a format used in electrophysiology and you want to make these files publicly available for the purpose of software building on that format, then this is the right place to contribute!

### Requirements
To contribute a dataset the following criteria need to be fulfilled
- You need to have the rights to publish the data files
- The data files need to be **small** in size (ideally in the range of kilobytes, **no more than 10MB**)

### How to add files

To add files to the repository please follow the steps below.

**1) On the [gin](https://gin.g-node.org) platform**
- Create a [gin account](https://gin.g-node.org/user/sign_up)
- Open an issue stating the format of files you would like to add. Please specify in this issue, which type of system is generating these files and in which software your files could be used as testing files. After reviewing the proposed format you will be added as a collaborator to the project.

**2) On your local computer**
- Install the gin client on your machine ([gin-cli setup instructions](https://gin.g-node.org/G-Node/Info/wiki/GIN+CLI+Setup))
- Log in with your gin-cli (`gin login`)
- Create a local copy of the repository on your machine (`gin get NeuralEnsemble/ephy_testing_data`)
- Create a new git branch to work on via `gin git checkout -b <my_branch_name>`
- Create a new subfolder with the corresponding system brand name or identify the folder to which to add your files.
- Copy your files in the new folder. Feel free to add an attribution to it, e.g. see [this readme](https://gin.g-node.org/NeuralEnsemble/ephy_testing_data/src/master/neuralynx/Cheetah_v5.5.1/README.txt).
- Commit your files via `gin commit <folder_name>`
- Lock the files via `gin lock *`
- Upload your changes to gin via `gin upload`

*Note:* You can also commit files using any other git-annex capable tool. However, make sure that the `.gitattributes` specifications are respected and files are committed in a locked state. Only the README and LICENCE file should be committed to git, all other files should be tracked by git-annex.

**3) On the [gin](https://gin.g-node.org)  platform**
- The new branch `<my_branch_name>` should be available at the [webpage](https://gin.g-node.org/NeuralEnsemble/ephy_testing_data). Verify that the changes are correctly registered in this branch.
- Open a pull request (PR) with your changes to the master branch of the `NeuralEnsemble/ephy_testing_data` repository. In your PR description please specify again what format you want to add, which type of system is generating these files and which software could make use of these.
- You will potentially receive comments from the repository maintainers asking you to change some details in your PR. Please do **not** merge your own pull request!
- After resolving the comments your files will be merged into the main repository.
Congratulation! Your files are now part of the growing collection of electrophysiology testing files and can now be used by any project to check for file format compatibility.


*Note:* Don't forget to switch back to the master branch after completion of your PR: `gin git checkout master`


## License

This Electrophysiology Testing Data is made available under the Open Database License: http://opendatacommons.org/licenses/odbl/1.0/. Any rights in individual contents of the database are licensed under the Database Contents License: https://creativecommons.org/licenses/by-sa/4.0/legalcode
